@@ -609,6 +609,10 @@ class Logger:
           the log file as argument and process to whatever it wants (custom compression, network
           sending, removing it, etc.).
 
+        Either way, if you use a custom function designed according to your preferences, you must be
+        very careful not to use the ``logger`` within your function. Otherwise, there is a risk that
+        your program hang because of a deadlock.
+
         .. _color:
 
         .. rubric:: The color markups
@@ -1078,6 +1082,7 @@ class Logger:
         reraise=False,
         onerror=None,
         exclude=None,
+        default=None,
         message="An error has been caught in function '{record[function]}', "
         "process '{record[process].name}' ({record[process].id}), "
         "thread '{record[thread].name}' ({record[thread].id}):"
@@ -1108,6 +1113,9 @@ class Logger:
         exclude : |Exception|, optional
             A type of exception (or a tuple of types) that will be purposely ignored and hence
             propagated to the caller without being logged.
+        default : optional
+            The value to be returned by the decorated function if an error occurred without being
+            re-raised.
         message : |str|, optional
             The message that will be automatically logged if an exception occurs. Note that it will
             be formatted with the ``record`` attribute.
@@ -1196,18 +1204,21 @@ class Logger:
                     async def catch_wrapper(*args, **kwargs):
                         with catcher:
                             return await function(*args, **kwargs)
+                        return default
 
                 elif inspect.isgeneratorfunction(function):
 
                     def catch_wrapper(*args, **kwargs):
                         with catcher:
                             return (yield from function(*args, **kwargs))
+                        return default
 
                 else:
 
                     def catch_wrapper(*args, **kwargs):
                         with catcher:
                             return function(*args, **kwargs)
+                        return default
 
                 functools.update_wrapper(catch_wrapper, function)
                 return catch_wrapper
@@ -1915,6 +1926,9 @@ class Logger:
             args = [arg() for arg in args]
             kwargs = {key: value() for key, value in kwargs.items()}
 
+        if capture and kwargs:
+            log_record["extra"].update(kwargs)
+
         if record:
             if "record" in kwargs:
                 raise TypeError(
@@ -1923,9 +1937,6 @@ class Logger:
                 )
             kwargs.update(record=log_record)
 
-        if capture and kwargs:
-            log_record["extra"].update(kwargs)
-
         if colors:
             if args or kwargs:
                 colored_message = Colorizer.prepare_message(message, args, kwargs)
